"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DELETE_INACTIVE_USERS_HISTORY = exports.DELETE_USER = exports.INSERT_REMOVE_USER = exports.GET_USER_INFO = void 0;
const apollo_boost_1 = require("apollo-boost");
exports.GET_USER_INFO = (0, apollo_boost_1.gql) `
  query GetUserInfo($emailId: String) {
    user_group(where: { user: { email_id: { _eq: $emailId } } }) {
      group {
        id
        display_name
      }
    }
    user_persona(where: { user: { email_id: { _eq: $emailId } } }) {
      persona {
        id
        display_name
      }
    }
    user_tenant(where: { user: { email_id: { _eq: $emailId } } }) {
      tenant {
        id
        name
      }
    }
    user(where: { email_id: { _eq: $emailId } }) {
      id
      display_name
      policies {
        policy {
          id
          statements {
            app_product_id
          }
        }
      }
      domain {
        id
        display_name
      }
    }
  }
`;
exports.INSERT_REMOVE_USER = (0, apollo_boost_1.gql) `
  mutation InsertRemoveUsers(
    $email_id: String!
    $display_name: String!
    $user_info: jsonb
  ) {
    insert_removed_users_one(
      object: {
        email_id: $email_id
        display_name: $display_name
        removed_data: $user_info
      }
    ) {
      id
    }
  }
`;
exports.DELETE_USER = (0, apollo_boost_1.gql) `
  mutation DeleteUser($emailId: String!) {
    delete_user_tenant(where: { user: { email_id: { _eq: $emailId } } }) {
      affected_rows
    }
    delete_user_persona(where: { user: { email_id: { _eq: $emailId } } }) {
      affected_rows
    }
    delete_policy(
      where: { subject: { user: { email_id: { _eq: $emailId } } } }
    ) {
      affected_rows
    }
    delete_user(where: { email_id: { _eq: $emailId } }) {
      affected_rows
    }
  }
`;
exports.DELETE_INACTIVE_USERS_HISTORY = (0, apollo_boost_1.gql) `
  mutation DeleteOldRemovedUsers($targetDate: timestamptz!) {
    delete_removed_users(where: { insert_time: { _lt: $targetDate } }) {
      affected_rows
    }
  }
`;
